capo
====

A very loose framework-y collection of css/javascript and template code I tend to always use.

Includes stickit.js, a jQuery plugin that:

* allows for multiple sticky elements
* allows them be combined with a sticky header
* allows for expanding/collapsing header navigation
* prevents overflow of the sticky element to the header or footer
